@@ -8,8 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef ATT_GRAPH_H
-#define ATT_GRAPH_H
+#pragma once
 
 #include <inttypes.h>
 #include "cdt.h"
@@ -18,14 +17,16 @@
 extern "C" {
 #endif
 
-#ifdef _WIN32
-#   ifdef EXPORT_CGRAPH
-#       define CGRAPH_API __declspec(dllexport)
-#   else
-#       define CGRAPH_API __declspec(dllimport)
-#   endif
+#ifdef GVDLL
+#ifdef EXPORT_CGRAPH
+#define CGRAPH_API __declspec(dllexport)
 #else
-#   define CGRAPH_API extern
+#define CGRAPH_API __declspec(dllimport)
+#endif
+#endif
+
+#ifndef CGRAPH_API
+#define CGRAPH_API /* nothing */
 #endif
 
 #ifndef FALSE
@@ -34,16 +35,6 @@ extern "C" {
 #ifndef TRUE
 #define TRUE (!FALSE)
 #endif
-#ifndef NOT
-#define	NOT(x)			(!(x))
-#endif
-#ifndef NIL
-#define NIL(type)		((type)0)
-#endif
-#define NILgraph		NIL(Agraph_t*)
-#define NILnode			NIL(Agnode_t*)
-#define NILedge			NIL(Agedge_t*)
-#define NILsym			NIL(Agsym_t*)
 
 typedef uint64_t IDTYPE;
 
@@ -191,11 +182,11 @@ struct Agdisc_s {		/* user's discipline */
 
 	/* default resource disciplines */
 
-CGRAPH_API Agmemdisc_t AgMemDisc;
-CGRAPH_API Agiddisc_t AgIdDisc;
-CGRAPH_API Agiodisc_t AgIoDisc;
+CGRAPH_API extern Agmemdisc_t AgMemDisc;
+CGRAPH_API extern Agiddisc_t AgIdDisc;
+CGRAPH_API extern Agiodisc_t AgIoDisc;
 
-CGRAPH_API Agdisc_t AgDefaultDisc;
+CGRAPH_API extern Agdisc_t AgDefaultDisc;
 
 struct Agdstate_s {
     void *mem;
@@ -256,7 +247,7 @@ CGRAPH_API Agraph_t *agread(void *chan, Agdisc_t * disc);
 CGRAPH_API Agraph_t *agmemread(const char *cp);
 CGRAPH_API Agraph_t *agmemconcat(Agraph_t *g, const char *cp);
 CGRAPH_API void agreadline(int);
-CGRAPH_API void agsetfile(char *);
+CGRAPH_API void agsetfile(const char *);
 CGRAPH_API Agraph_t *agconcat(Agraph_t * g, void *chan, Agdisc_t * disc);
 CGRAPH_API int agwrite(Agraph_t * g, void *chan);
 CGRAPH_API int agisdirected(Agraph_t * g);
@@ -294,7 +285,6 @@ CGRAPH_API Agraph_t *agraphof(void* obj);
 CGRAPH_API Agraph_t *agroot(void* obj);
 CGRAPH_API int agcontains(Agraph_t *, void *);
 CGRAPH_API char *agnameof(void *);
-CGRAPH_API int agrelabel(void *obj, char *name);	/* scary */
 CGRAPH_API int agrelabel_node(Agnode_t * n, char *newname);
 CGRAPH_API int agdelete(Agraph_t * g, void *obj);
 CGRAPH_API int agdelsubg(Agraph_t * g, Agraph_t * sub);	/* could be agclose */
@@ -303,11 +293,11 @@ CGRAPH_API int agdeledge(Agraph_t * g, Agedge_t * arg_e);
 CGRAPH_API int agobjkind(void *);
 
 /* strings */
-CGRAPH_API char *agstrdup(Agraph_t *, char *);
-CGRAPH_API char *agstrdup_html(Agraph_t *, char *);
-CGRAPH_API int aghtmlstr(char *);
-CGRAPH_API char *agstrbind(Agraph_t * g, char *);
-CGRAPH_API int agstrfree(Agraph_t *, char *);
+CGRAPH_API char *agstrdup(Agraph_t *, const char *);
+CGRAPH_API char *agstrdup_html(Agraph_t *, const char *);
+CGRAPH_API int aghtmlstr(const char *);
+CGRAPH_API char *agstrbind(Agraph_t * g, const char *);
+CGRAPH_API int agstrfree(Agraph_t *, const char *);
 CGRAPH_API char *agcanon(char *, int);
 CGRAPH_API char *agstrcanon(char *, char *);
 CGRAPH_API char *agcanonStr(char *str);  /* manages its own buf */
@@ -336,24 +326,26 @@ struct Agdatadict_s {		/* set of dictionaries per graph */
     } dict;
 };
 
-CGRAPH_API Agsym_t *agattr(Agraph_t * g, int kind, char *name, char *value);
+CGRAPH_API Agsym_t *agattr(Agraph_t * g, int kind, char *name,
+                           const char *value);
 CGRAPH_API Agsym_t *agattrsym(void *obj, char *name);
 CGRAPH_API Agsym_t *agnxtattr(Agraph_t * g, int kind, Agsym_t * attr);
 CGRAPH_API int      agcopyattr(void *oldobj, void *newobj);
 
-CGRAPH_API void *agbindrec(void *obj, char *name, unsigned int size,
+CGRAPH_API void *agbindrec(void *obj, const char *name, unsigned int recsize,
 		       int move_to_front);
-CGRAPH_API Agrec_t *aggetrec(void *obj, char *name, int move_to_front);
-CGRAPH_API int agdelrec(void *obj, char *name);
-CGRAPH_API void aginit(Agraph_t * g, int kind, char *rec_name, int rec_size,
-		   int move_to_front);
+CGRAPH_API Agrec_t *aggetrec(void *obj, const char *name, int move_to_front);
+CGRAPH_API int agdelrec(void *obj, const char *name);
+CGRAPH_API void aginit(Agraph_t * g, int kind, const char *rec_name,
+                       int rec_size, int move_to_front);
 CGRAPH_API void agclean(Agraph_t * g, int kind, char *rec_name);
 
 CGRAPH_API char *agget(void *obj, char *name);
 CGRAPH_API char *agxget(void *obj, Agsym_t * sym);
-CGRAPH_API int agset(void *obj, char *name, char *value);
-CGRAPH_API int agxset(void *obj, Agsym_t * sym, char *value);
-CGRAPH_API int agsafeset(void* obj, char* name, char* value, char* def);
+CGRAPH_API int agset(void *obj, char *name, const char *value);
+CGRAPH_API int agxset(void *obj, Agsym_t * sym, const char *value);
+CGRAPH_API int agsafeset(void* obj, char* name, const char* value,
+                         const char* def);
 
 /* definitions for subgraphs */
 CGRAPH_API Agraph_t *agsubg(Agraph_t * g, char *name, int cflag);	/* constructor */
@@ -422,10 +414,10 @@ CGRAPH_API agusererrf agseterrf(agusererrf);
 #define TAILPORT_ID		"tailport"
 #define HEADPORT_ID		"headport"
 
-CGRAPH_API Agdesc_t Agdirected;
-CGRAPH_API Agdesc_t Agstrictdirected;
-CGRAPH_API Agdesc_t Agundirected;
-CGRAPH_API Agdesc_t Agstrictundirected;
+CGRAPH_API extern Agdesc_t Agdirected;
+CGRAPH_API extern Agdesc_t Agstrictdirected;
+CGRAPH_API extern Agdesc_t Agundirected;
+CGRAPH_API extern Agdesc_t Agstrictundirected;
 
 /* fast graphs */
 void agflatten(Agraph_t * g, int flag);
@@ -458,4 +450,3 @@ and edges are embedded in main graph objects but allocated separately in subgrap
 #ifdef __cplusplus
 }
 #endif
-#endif
